( cd usr/lib ; rm -rf libavcodec.so )
( cd usr/lib ; ln -sf libavcodec-0.4.9-pre1.so libavcodec.so )
( cd usr/lib ; rm -rf libavformat.so )
( cd usr/lib ; ln -sf libavformat-0.4.9-pre1.so libavformat.so )
